@@ -66,7 +66,7 @@ int main(int argc, char **argv)
     MainWindow *win = new MainWindow;
 
     app.setMainWidget(win);
-    app.connect(&app, TQT_SIGNAL(lastWindowClosed()), TQT_SLOT(quit()));
+    app.connect(&app, TQ_SIGNAL(lastWindowClosed()), TQ_SLOT(quit()));
     win->show();
     win->resize(500, 300);
     
