@@ -33,7 +33,7 @@ namespace ResultList {
 
 class ResultListView : public TDEListView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
